@@ -66,7 +66,7 @@ class __Executor(object):
                 description = values['description']
                 if not name:
                     name = self.function.__name__
-            if list_:
+            elif list_:
                 list_values = get_list_values(
                     self.keys,
                     self.description_key,
