@@ -1,12 +1,16 @@
 import os
 import traceback
 from typing import Callable, Any, Optional
+
 from .event import Event
 
-from zappa.asynchronous import run as zappa_run
 
-
-def log_exception(name: str, description: str, trb: Optional[str] = None, function_name: Optional[str] = '') -> bool:
+def log_exception(
+    name: str,
+    description: str,
+    trb: Optional[str] = None,
+    function_name: Optional[str] = '',
+) -> bool:
     """
     :param name: str
     :param description: str
@@ -23,7 +27,9 @@ def log_exception(name: str, description: str, trb: Optional[str] = None, functi
     }
     event = Event(**init_kwargs)
     if not trb:
-        trb = str(traceback.format_exc()).replace('func_result = function', function_name)
+        trb = str(traceback.format_exc()).replace(
+            'func_result = function', function_name
+        )
     return event.log_exception(name, description, trb=trb)
 
 
@@ -31,6 +37,10 @@ def run(function: Callable[..., Any], **kwargs) -> any:
     """
     function must be a top level function, not class method, and not decorated function
     """
+    try:
+        from zappa.asynchronous import run as zappa_run
+    except:
+        raise ImportError('u need to install zappa=0.50.0')
     if "kwargs" in kwargs:
         kwargs = kwargs["kwargs"]
     if not os.environ.get("AWS_LAMBDA_FUNCTION_NAME"):
